import * as moment from 'moment';
import {
  ForbiddenException,
  forwardRef,
  Inject,
  Injectable,
} from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { FindManyOptions, Repository } from 'typeorm';
import { Equipo } from '../equipo/entity/equipo.entity';
import { EquipoMotivo } from './entity/equipo-motivo.entity';
import { Operador } from '../operador/entity/operador.entity';
import { Status } from '../status/entity/status.entity';
import { EquipoService } from '../equipo/equipo.service';

@Injectable()
export class EquipoMotivoService {
  constructor(
    @InjectRepository(EquipoMotivo)
    private repository: Repository<EquipoMotivo>,
    @Inject(forwardRef(() => EquipoService))
    private equipoService: EquipoService,
  ) {}

  async create(
    equipo: Equipo,
    operador: Operador,
    status: Status,
    motivo: string,
  ): Promise<EquipoMotivo> {
    // Cramos y guardamos registro
    return this.repository.save(
      this.repository.create({
        fecha_creacion: moment().toDate(),
        motivo,
        equipo,
        operador,
        status,
      }),
    );
  }

  async findAllByIdEquipo(
    operador: Operador,
    id_equipo: number,
    pagina?: number,
  ): Promise<EquipoMotivo[] | [EquipoMotivo[], number]> {
    const equipo = await this.equipoService.findById(id_equipo);
    const options: FindManyOptions<EquipoMotivo> = { where: { equipo } };

    // Validamos que el equipo pertenezca a la institución del operador
    if (
      equipo.carrito.modulo.institucion.id_institucion !=
      operador.institucion.id_institucion
    )
      throw new ForbiddenException(
        'No puedes acceder a esta información porque no le pertenece a tu institución.',
      );
    // Si se mandó página significa que requiere paginación
    if (pagina) {
      options.skip = (pagina - 1) * 25;
      options.take = 25;
      return this.repository.findAndCount(options);
    } else return this.repository.find(options);
  }
}
