import { Controller, Get, Query, Request, UseGuards } from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiOperation, ApiQuery } from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { ModuloMotivoService } from './modulo-motivo.service';
import { ValidarUsuarioService } from '../validar-usuario/validar-usuario.service';
import { Operador } from '../operador/entity/operador.entity';
import { GetDto } from './dto/input/get.dto';
import { ModuloMotivoOutputDto } from './dto/output/modulo-motivo.dto';

@Controller('modulo-motivo')
export class ModuloMotivoController {
  constructor(
    private moduloMotivoService: ModuloMotivoService,
    private validarUsuarioService: ValidarUsuarioService,
  ) {}

  @Serealize(ModuloMotivoOutputDto)
  @Get()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description:
      'Información de 25 cambios de status que ha tenido un carrito dependiendo de la página en la que se encuentra el alumno.',
  })
  @ApiBearerAuth('jwt')
  @ApiQuery({
    description: 'Id del carrito.',
    name: 'id_carrito',
    type: 'string',
  })
  @ApiQuery({
    description: 'Página en la que se encuentra el usuario.',
    name: 'pagina',
    type: 'string',
  })
  get(@Request() req, @Query() query: GetDto) {
    const operador: Operador = req.user.operador;

    this.validarUsuarioService.validarAdminOperador(operador);
    return this.moduloMotivoService.findAllByIdModulo(
      parseInt(query.id_modulo),
      parseInt(query.pagina),
    );
  }
}
