import { Controller, Get, Request, UseGuards } from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiOperation, ApiTags } from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { StatusService } from './status.service';
import { ValidarUsuarioService } from '../validar-usuario/validar-usuario.service';
import { StatusOutputDto } from './dto/output/status.dto';
import { Operador } from '../operador/entity/operador.entity';

@Controller('status')
@ApiTags('status')
export class StatusController {
  constructor(
    private statusService: StatusService,
    private validarUsuarioService: ValidarUsuarioService,
  ) {}

  @Serealize(StatusOutputDto)
  @Get()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({ description: 'Endpoint que retorna todos los status.' })
  @ApiBearerAuth('jwt')
  get(@Request() req) {
    const operador: Operador = req.user.operador;

    this.validarUsuarioService.validarOperador(operador);
    return this.statusService.findAll();
  }
}
